@@ -29,10 +29,6 @@ __END__
 
 WWW::CurlOO::Share - Perl interface for curl_share_* functions
 
-=head1 WARNING
-
-B<THIS MODULE IS UNDER HEAVY DEVELOPEMENT AND SOME INTERFACE MAY CHANGE YET.>
-
 =head1 SYNOPSIS
 
  use WWW::CurlOO::Share qw(:constants);
@@ -131,21 +127,21 @@ Reffer to libcurl documentation for more detailed info on each of those.
 
 =item CURLSHOPT_LOCKFUNC ( CURLSHOPT_USERDATA )
 
-Lock callback receives 4 arguments: easy object, lock data, lock access,
-and CURLSHOPT_USERDATA value.
+Lock callback receives 5 arguments: share object, easy object, lock data,
+lock access, and CURLSHOPT_USERDATA value. Easy may be undefined in some cases.
 
  sub cb_lock {
-     my ( $easy, $data, $locktype, $uservar ) = @_;
+     my ( $share, $easy, $data, $locktype, $uservar ) = @_;
      # ... lock ...
  }
 
 =item CURLSHOPT_UNLOCKFUNC ( CURLSHOPT_USERDATA )
 
-Unlock callback receives 3 arguments: easy object, lock data, and
-CURLSHOPT_USERDATA value.
+Unlock callback receives 4 arguments: share object, easy object, lock data, and
+CURLSHOPT_USERDATA value. Easy may be undefined in some cases.
 
  sub cb_unlock {
-     my ( $easy, $data, $uservar ) = @_;
+     my ( $share, $easy, $data, $uservar ) = @_;
      # ... unlock ...
  }
 
@@ -157,6 +153,9 @@ CURLSHOPT_USERDATA value.
 L<WWW::CurlOO>
 L<WWW::CurlOO::Easy>
 L<WWW::CurlOO::Multi>
+L<WWW::CurlOO::examples(3pm)>
+L<libcurl-share(3)>
+L<libcurl-errors(3)>
 
 =head1 COPYRIGHT
 
